@@ -2,12 +2,9 @@
 
 package Games::Nintendo::Mario::Hearts;
 
-our $VERSION = '0.09_01';
-
 use base qw(Games::Nintendo::Mario);
 
-use strict;
-use warnings;
+our $VERSION = 0.01;
 
 sub _states { qw[normal] }
 sub _items  { qw[heart] }
